@@ -297,6 +297,11 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The relation item has a comparison operation set, but does not support any comparisons.")
 	},
 
+	{ "relation-item-redefined",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("This relation item has already been defined once for this or a different relation type. Please do not redefine relations.")
+	},
+
 	{ "relation-memory-in-requires",
 	  AS_ISSUE_SEVERITY_INFO,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
@@ -524,6 +529,25 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("This generic component is missing a long description. It may be useful to add one."),
 	},
 
+	{ "desktop-app-launchable-missing",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("This `desktop-application` component is missing a `desktop-id` launchable tag. "
+	     "This means that this application can not be launched and has no association with its desktop-entry file. "
+	     "It also means no icon data or category information from the desktop-entry file will be available, which "
+	     "will result in this application being ignored entirely."),
+	},
+
+	{ "desktop-app-launchable-omitted",
+	  AS_ISSUE_SEVERITY_INFO,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("This `desktop-application` component has no `desktop-id` launchable tag, "
+	     "however it contains all the necessary information to display the application. "
+	     "The omission of the launchable entry means that this application can not be launched directly from "
+	     "installers or software centers. If this is intended, this information can be ignored, otherwise "
+	     "it is strongly recommended to add a launchable tag as well."),
+	},
+
 	{ "console-app-no-binary",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
@@ -601,6 +625,11 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The category name is not valid. Refer to the XDG Menu Specification for a list of valid category names."),
 	},
 
+	{ "app-categories-missing",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("This component is in no valid categories, even though it should be. Please check its metainfo file and desktop-entry file."),
+	},
+
 	{ "screenshot-caption-too-long",
 	  AS_ISSUE_SEVERITY_PEDANTIC,
 	  N_("The screenshot caption is too long (should be <= 100 characters)"),
@@ -638,9 +667,9 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The metainfo filename does not match the component ID."),
 	},
 
-	{ "desktop-file-read-failed",
+	{ "desktop-file-load-failed",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  N_("Unable to read the .desktop file associated with this component."),
+	  N_("Unable to load the desktop-entry file associated with this component."),
 	},
 
 	{ "desktop-file-not-found",
@@ -648,17 +677,44 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("This component metadata refers to a non-existing .desktop file."),
 	},
 
-	{ "desktop-file-category-invalid",
+	{ "desktop-entry-category-invalid",
 	  AS_ISSUE_SEVERITY_WARNING,
-	  N_("The category defined in the .desktop file is not valid. Refer to the XDG Menu Specification for a list of valid categories."),
+	  N_("A category defined in the desktop-entry file is not valid. Refer to the XDG Menu Specification for a list of valid categories."),
 	},
 
-	{ "dir-no-metadata.found",
+	{ "desktop-entry-bad-data",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("Error while reading some data from the desktop-entry file."),
+	},
+
+	{ "desktop-entry-value-invalid-chars",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("The value of this desktop-entry field contains invalid or non-printable UTF-8 characters, which can not be displayed properly."),
+	},
+
+	{ "desktop-entry-value-quoted",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("This desktop-entry field value is quoted, which is likely unintentional."),
+	},
+
+	{ "desktop-entry-hidden-set",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("This desktop-entry file has the 'Hidden' property set. This is wrong for vendor-installed .desktop files, and "
+	     "nullifies all effects this .desktop file has (including MIME associations), which most certainly is not intentional."),
+	},
+
+	{ "desktop-entry-empty-onlyshowin",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("This desktop-entry file has the 'OnlyShowIn' property set with an empty value. This might not be intended, as this will hide "
+	     "the application from all desktops. If you do want to hide the application from all desktops, using 'NoDisplay=true' is more explicit."),
+	},
+
+	{ "dir-no-metadata-found",
 	  AS_ISSUE_SEVERITY_INFO,
 	  N_("No AppStream metadata was found in this directory or directory tree."),
 	},
 
-	{ "dir-applications-not.found",
+	{ "dir-applications-not-found",
 	  AS_ISSUE_SEVERITY_PEDANTIC, /* pedantic because not everything which has metadata is an application */
 	  N_("No XDG applications directory found."),
 	},
@@ -701,6 +757,12 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
 	  N_("The release is missing either the `date` (preferred) or the `timestamp` property."),
 	},
+
+	{ "release-timestamp-invalid",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("The release timestamp is invalid."),
+	},
+
 	{ "artifact-type-invalid",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
@@ -821,6 +883,12 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("This color is not a valid HTML color code."),
 	},
 
+	{ "metainfo-localized-keywords-tag",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("A <keywords/> tag must not be localized in metainfo files (upstream metadata). "
+	     "Localize the individual keyword entries instead.")
+	},
+
 	{ NULL, AS_ISSUE_SEVERITY_UNKNOWN, NULL }
 };
 
