@@ -127,8 +127,7 @@ test_safe_assign ()
 static void
 test_categories ()
 {
-	g_autoptr(GPtrArray) default_cats;
-
+	g_autoptr(GPtrArray) default_cats = NULL;
 	default_cats = as_get_default_categories (TRUE);
 	g_assert_cmpint (default_cats->len, ==, 10);
 }
@@ -274,6 +273,7 @@ test_locale_compat (void)
 	g_assert_true (!as_utils_locale_is_compatible ("ca@valencia", "de"));
 	g_assert_true (!as_utils_locale_is_compatible ("de_CH", "de_DE"));
 	g_assert_true (as_utils_locale_is_compatible ("de", "de_CH"));
+	g_assert_true (as_utils_locale_is_compatible ("C", "C"));
 }
 
 /**
