@@ -21,6 +21,7 @@
 #include <glib.h>
 #include "appstream.h"
 #include "as-component-private.h"
+#include "as-validator-issue-tag.h"
 
 #include "as-test-utils.h"
 
@@ -41,7 +42,7 @@ typedef struct {
 static gboolean
 _astest_validate_sample_fname (AsValidator *validator, const gchar *basename)
 {
-	g_autofree gchar *fname;
+	g_autofree gchar *fname = NULL;
 	g_autoptr(GFile) file = NULL;
 
 	fname = g_build_filename (datadir, basename, NULL);
@@ -120,6 +121,28 @@ _astest_check_validate_issues (GList *issues, AsVResultCheck *checks_all)
 	}
 }
 
+/**
+ * test_validator_tag_sanity:
+ */
+static void
+test_validator_tag_sanity ()
+{
+	g_autoptr(GHashTable) tag_map = NULL;
+	tag_map = g_hash_table_new_full (g_str_hash,
+					 g_str_equal,
+					 g_free,
+					 NULL);
+	for (guint i = 0; as_validator_issue_tag_list[i].tag != NULL; i++) {
+		gboolean r = g_hash_table_insert (tag_map,
+						  g_strdup (as_validator_issue_tag_list[i].tag),
+						  &as_validator_issue_tag_list[i]);
+		if (!r) {
+			g_critical ("Duplicate issue-tag '%s' found in tag list. This is a bug in the validator.", as_validator_issue_tag_list[i].tag);
+			g_assert_not_reached ();
+		}
+	}
+}
+
 /**
  * test_validator_manyerrors_desktopapp:
  *
@@ -209,6 +232,10 @@ test_validator_manyerrors_desktopapp ()
 		  "", -1,
 		  AS_ISSUE_SEVERITY_INFO,
 		},
+		{ "desktop-app-launchable-missing",
+		  "", -1,
+		  AS_ISSUE_SEVERITY_ERROR,
+		},
 
 		{ NULL, NULL, 0, AS_ISSUE_SEVERITY_UNKNOWN }
 	};
@@ -235,29 +262,37 @@ test_validator_relationissues ()
 
 	AsVResultCheck expected_results[] =  {
 		{ "relation-control-value-invalid",
-		  "telekinesis", 22,
+		  "telekinesis", 26,
 		  AS_ISSUE_SEVERITY_WARNING,
 		},
 		{ "relation-item-has-vercmp",
-		  "gt", 23,
+		  "gt", 27,
 		  AS_ISSUE_SEVERITY_INFO,
 		},
 		{ "relation-item-invalid-vercmp",
-		  "gl", 24,
+		  "gl", 28,
 		  AS_ISSUE_SEVERITY_ERROR,
 		},
 		{ "relation-display-length-side-property-invalid",
-		  "alpha", 27,
+		  "alpha", 31,
 		  AS_ISSUE_SEVERITY_WARNING,
 		},
 		{ "relation-display-length-value-invalid",
-		  "bleh", 25,
+		  "bleh", 29,
+		  AS_ISSUE_SEVERITY_WARNING,
+		},
+		{ "relation-item-redefined",
+		  "requires & recommends", 32,
 		  AS_ISSUE_SEVERITY_WARNING,
 		},
 		{ "releases-info-missing",
 		  "", -1,
 		  AS_ISSUE_SEVERITY_PEDANTIC,
 		},
+		{ "desktop-app-launchable-missing",
+		  "", -1,
+		  AS_ISSUE_SEVERITY_ERROR,
+		},
 
 		{ NULL, NULL, 0, AS_ISSUE_SEVERITY_UNKNOWN }
 	};
@@ -270,6 +305,85 @@ test_validator_relationissues ()
 	g_assert_false (ret);
 }
 
+/**
+ * test_validator_relationissues:
+ *
+ * Test requires/recommends & Co.
+ */
+static void
+test_validator_overrides ()
+{
+	gboolean ret;
+	g_autoptr(GList) issues = NULL;
+	gboolean has_noreltime_issue = FALSE;
+	g_autoptr(GError) error = NULL;
+
+	const gchar *SAMPLE_XML = "<component>\n"
+				  "  <id>org.example.Test</id>\n"
+				  "  <name>Test</name>\n"
+				  "  <summary>Just a unittest.</summary>\n"
+				  "  <description>\n"
+				  "    <p>First paragraph</p>\n"
+				  "  </description>\n"
+				  "  <icon type=\"stock\">test-icon</icon>\n"
+				  "  <releases>\n"
+				  "    <release type=\"stable\" version=\"1.0\"/>\n"
+				  "  </releases>\n"
+				  "</component>\n";
+
+	g_autoptr(AsValidator) validator = as_validator_new ();
+
+	/* try without override */
+	ret = as_validator_validate_data (validator, SAMPLE_XML);
+	g_assert_false (ret);
+
+	has_noreltime_issue = FALSE;
+	issues = as_validator_get_issues (validator);
+	for (GList *l = issues; l != NULL; l = l->next) {
+		AsValidatorIssue *issue = AS_VALIDATOR_ISSUE (l->data);
+		const gchar *tag = as_validator_issue_get_tag (issue);
+
+		if (g_strcmp0 (tag, "release-time-missing") == 0) {
+			has_noreltime_issue = TRUE;
+			g_assert_cmpint (as_validator_issue_get_severity (issue), ==, AS_ISSUE_SEVERITY_ERROR);
+			break;
+		}
+	}
+	g_assert_true (has_noreltime_issue);
+	g_list_free (g_steal_pointer (&issues));
+
+	/* apply override and check again */
+	as_validator_clear_issues (validator);
+
+	/* try something invalid */
+	ret = as_validator_add_override (validator, "cid-punctuation-prefix", AS_ISSUE_SEVERITY_INFO, &error);
+	g_assert_error (error, AS_VALIDATOR_ERROR, AS_VALIDATOR_ERROR_OVERRIDE_INVALID);
+	g_assert_false (ret);
+	g_clear_error (&error);
+
+	/* npw test an override that works */
+	ret = as_validator_add_override (validator, "release-time-missing", AS_ISSUE_SEVERITY_PEDANTIC, &error);
+	g_assert_no_error (error);
+	g_assert_true (ret);
+
+	ret = as_validator_validate_data (validator, SAMPLE_XML);
+	g_assert_false (ret);
+
+	has_noreltime_issue = FALSE;
+	issues = as_validator_get_issues (validator);
+	for (GList *l = issues; l != NULL; l = l->next) {
+		AsValidatorIssue *issue = AS_VALIDATOR_ISSUE (l->data);
+		const gchar *tag = as_validator_issue_get_tag (issue);
+
+		if (g_strcmp0 (tag, "release-time-missing") == 0) {
+			has_noreltime_issue = TRUE;
+			g_assert_cmpint (as_validator_issue_get_severity (issue), ==, AS_ISSUE_SEVERITY_PEDANTIC);
+			break;
+		}
+	}
+	g_assert_true (has_noreltime_issue);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -290,8 +404,10 @@ main (int argc, char **argv)
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask (NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
+	g_test_add_func ("/AppStream/Validate/TagSanity", test_validator_tag_sanity);
 	g_test_add_func ("/AppStream/Validate/DesktopAppManyErrors", test_validator_manyerrors_desktopapp);
 	g_test_add_func ("/AppStream/Validate/RelationIssues", test_validator_relationissues);
+	g_test_add_func ("/AppStream/Validate/Overrides", test_validator_overrides);
 
 	ret = g_test_run ();
 	g_free (datadir);
