@@ -242,7 +242,7 @@ test_appstream_write_locale ()
 				    "    <keyword>internet</keyword>\n"
 				    "    <keyword>web</keyword>\n"
 				    "    <keyword>browser</keyword>\n"
-				    "    <keyword>navigateur</keyword>\n"
+				    "    <keyword xml:lang=\"fr_FR\">navigateur</keyword>\n"
 				    "  </keywords>\n"
 				    "</component>\n";
 
@@ -663,6 +663,8 @@ test_xml_read_url (void)
 					 "  <url type=\"faq\">https://example.org/faq</url>\n"
 					 "  <url type=\"donation\">https://example.org/donate</url>\n"
 					 "  <url type=\"contact\">https://example.org/contact</url>\n"
+					 "  <url type=\"vcs-browser\">https://example.org/source</url>\n"
+					 "  <url type=\"contribute\">https://example.org/contribute</url>\n"
 					 "</component>\n";
 
 	cpt = as_xml_test_read_data (xmldata_languages, AS_FORMAT_STYLE_METAINFO);
@@ -672,6 +674,8 @@ test_xml_read_url (void)
 	g_assert_cmpstr (as_component_get_url (cpt, AS_URL_KIND_FAQ), ==, "https://example.org/faq");
 	g_assert_cmpstr (as_component_get_url (cpt, AS_URL_KIND_DONATION), ==, "https://example.org/donate");
 	g_assert_cmpstr (as_component_get_url (cpt, AS_URL_KIND_CONTACT), ==, "https://example.org/contact");
+	g_assert_cmpstr (as_component_get_url (cpt, AS_URL_KIND_VCS_BROWSER), ==, "https://example.org/source");
+	g_assert_cmpstr (as_component_get_url (cpt, AS_URL_KIND_CONTRIBUTE), ==, "https://example.org/contribute");
 }
 
 /**
@@ -1078,6 +1082,10 @@ test_appstream_write_metainfo_to_collection (void)
 					"    </ul>\n"
 					"    <p xml:lang=\"de\">Absatz2</p>\n"
 					"  </description>\n"
+					"  <keywords>\n"
+					"    <keyword>supercalifragilisticexpialidocious</keyword>\n"
+					"    <keyword xml:lang=\"de\">Superkalifragilistischexpiallegetisch</keyword>\n"
+					"  </keywords>\n"
 					"  <icon type=\"cached\" width=\"20\" height=\"20\">test_writetest.png</icon>\n"
 					"  <icon type=\"cached\" width=\"40\" height=\"40\">test_writetest.png</icon>\n"
 					"  <icon type=\"stock\">xml-writetest</icon>\n"
@@ -1128,6 +1136,12 @@ test_appstream_write_metainfo_to_collection (void)
 					   "    <icon type=\"cached\" width=\"20\" height=\"20\">test_writetest.png</icon>\n"
 					   "    <icon type=\"cached\" width=\"40\" height=\"40\">test_writetest.png</icon>\n"
 					   "    <icon type=\"stock\">xml-writetest</icon>\n"
+					   "    <keywords>\n"
+					   "      <keyword>supercalifragilisticexpialidocious</keyword>\n"
+					   "    </keywords>\n"
+					   "    <keywords xml:lang=\"de\">\n"
+					   "      <keyword>Superkalifragilistischexpiallegetisch</keyword>\n"
+					   "    </keywords>\n"
 					   "    <releases>\n"
 					   "      <release type=\"stable\" version=\"1.0\" timestamp=\"1460412000\"/>\n"
 					   "    </releases>\n"
